# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['file_grouper']

package_data = \
{'': ['*']}

install_requires = \
['click>=8.0.4,<9.0.0']

entry_points = \
{'console_scripts': ['group_file = file_grouper.file_grouper:group_file',
                     'hello = file_grouper.console:hello']}

setup_kwargs = {
    'name': 'file-grouper',
    'version': '0.1.1',
    'description': 'Group file based on file name pattern defined by regex.',
    'long_description': None,
    'author': 'Yu Wang',
    'author_email': 'anselmwang@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)



import os
import re
import shutil

import click


@click.command()
@click.option("--dryrun/--no-dryrun", default=True)
@click.option("--verbose", is_flag=True)
@click.option("--key_regex", required=True, type=str)
@click.option("--group_no", default=0)
@click.option("--dst_root", default=".", help="destiation root folder")
@click.option("--force", is_flag=True)
@click.argument("files", nargs=-1)
def group_file(dryrun, verbose, key_regex, group_no, dst_root, force, files):
    """Given FILE_PATTERN (glob), for each file, extract key by KEY_REGEX and GROUP_NO,
    copy the file to folder with name of extracted `key`"""
    if verbose:
        click.echo(f"key_regex={key_regex}")
    key_re = re.compile(key_regex)
    for file_path in files:
        m = key_re.search(file_path)
        key = m.group(group_no)

        dst = os.path.join(dst_root, key)
        print(f"{file_path} --> {key}/")
        dst_file_path = os.path.join(dst, os.path.basename(file_path))
        if os.path.exists(dst_file_path) and not force:
            click.echo(f"Destination file '{dst_file_path}' exists.", err=True)
            return -1

        if not dryrun:
            os.makedirs(dst, exist_ok=True)
            shutil.copy(file_path, dst_file_path)
